@@ -14,6 +14,7 @@ def fanout_action(action_id):
     Fan-out action to feeds. Usually called when writing an action.
     """
     from activity.models import Action, Follow, Stream
+    User = get_user_model()
     logger.info('Populating feeds')
 
     try:
@@ -27,23 +28,24 @@ def fanout_action(action_id):
         return False
 
     if action.is_global:
-        logger.info('This action is global, skipping stream population')
-        return True
+        logger.info('This action is global. Populating all streams.')
 
-    # Action is not global, populate followers' streams
-    User = get_user_model()
-    user_type = ContentType.objects.get_for_model(User)
-
-    followers = Follow.objects.filter(
-        content_type=user_type,
-        object_id=action.actor.pk,
-        actor_only=True).values_list('user__pk')
-
-    if followers.count():
-        followers_ids, = zip(*followers)
-        Stream.objects.fanout(action, followers_ids)
+        user_ids = User.objects.values_list('pk', flat=True)
+        Stream.objects.fanout(action, user_ids)
         logger.info('Stream population completed')
     else:
-        logger.info('No followers, skipping')
+        # Action is not global, populate followers' streams
+        user_type = ContentType.objects.get_for_model(User)
+
+        followers = Follow.objects.filter(
+            content_type=user_type,
+            object_id=action.actor.pk,
+            actor_only=True).values_list('user__pk', flat=True)
+
+        if followers.count():
+            Stream.objects.fanout(action, followers)
+            logger.info('Stream population completed')
+        else:
+            logger.info('No followers, skipping')
 
     return True
